# Table of Contents

- [modeling-guidelines-v3](<./modeling-guidelines-v3.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Modeling Guidelines (Meta Model v3)](<./Modeling-Guidelines-Meta-Model-v3.md>)
  - [Full Modeling Example - LeanIX as an Application](<./Modeling-Guidelines-Meta-Model-v3/Full-Modeling-Example---LeanIX-as-an-Application.md>)
  - [Tags vs. Custom Attributes](<./Modeling-Guidelines-Meta-Model-v3/Tags-vs.-Custom-Attributes.md>)
  - [Relations: Parent / Child vs. Requires / Required by vs. Explicit Relations](<./Modeling-Guidelines-Meta-Model-v3/Relations-Parent--Child-vs.-Requires--Required-by-vs.-Explicit-Relations.md>)
  - [Was this page helpful?](<./Modeling-Guidelines-Meta-Model-v3/Was-this-page-helpful.md>)
